@@ -16,21 +16,31 @@ class Request:
         if not self.api_key:
             raise InvalidKeyException('Empty key provided')
 
-    def make_request(self, method, path, request_json=None):
+    def make_request(self, method, path, request_json=None, params=None):
         '''make request
 
         :param str method: Method to use
         :param str path: Endpoint path
         :param dict request_json: Request json data
+        :param dict params: URL params
         :return object: Returns requests object
         '''
         s = requests.Session()
-        s.headers.update({'Authorization': 'Bearer {}'.format(self.api_key)})
+        s.headers.update(
+            {
+                'Authorization': 'Bearer {}'.format(self.api_key),
+                'Accept': 'application/json',
+            }
+        )
         data = None
         if method == 'get':
-            data = s.get(path)
+            data = s.get(path, params=params)
         elif method == 'post':
-            data = s.post(path, json=request_json)
+            data = s.post(path, json=request_json, params=params)
+        elif method == 'put':
+            data = s.put(path, json=request_json)
+        elif method == 'patch':
+            data = s.patch(path, json=request_json)
         elif method == 'delete':
             data = s.delete(path)
         logging.debug(data.content)
